==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/speech/translations/speech_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Benachrichtigung</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Maximale Anzahl an Buchstaben, die vorgesagt werden sollen</translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation>Nachricht zu lang (männlich)</translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation>Nachricht zu lang (weiblich)</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Stimme</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frequenz</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Grundfrequenz</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodie</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Klang</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>System Audio</translation>
    </message>
    <message>
        <source>aRts</source>
        <translation>aRts</translation>
    </message>
    <message>
        <source>Esd</source>
        <translation>Esd</translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation>Dsp</translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation>Gerät Dsp</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Klatt (braucht dsp)</translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation>Programm Speech</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation>männliche Stimme</translation>
    </message>
    <message>
        <source>Female format</source>
        <translation>weibliche Stimme</translation>
    </message>
</context>
</TS>

==> kadu_1.3.orig.tar.bz2: kadu-1.3/plugins/speech/translations/speech_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Benachrichtigung</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Maximale Anzahl an Buchstaben, die vorgesagt werden sollen</translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation>Nachricht zu lang (männlich)</translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation>Nachricht zu lang (weiblich)</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Stimme</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frequenz</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Grundfrequenz</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodie</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Klang</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>System Audio</translation>
    </message>
    <message>
        <source>aRts</source>
        <translation>aRts</translation>
    </message>
    <message>
        <source>Esd</source>
        <translation>Esd</translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation>Dsp</translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation>Gerät Dsp</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Klatt (braucht dsp)</translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation>Programm Speech</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation>männliche Stimme</translation>
    </message>
    <message>
        <source>Female format</source>
        <translation>weibliche Stimme</translation>
    </message>
</context>
</TS>
